==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pl.ts--</translatorcomment>
        <translation type="unfinished">Zamykanie rysunku...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translatorcomment>--exact match--
--file: qt_help_pl.ts--
Nienazwany
(Nienazwany)</translatorcomment>
        <translation type="unfinished">Nienazwany</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Ładowanie...</translatorcomment>
        <translation type="unfinished">Ładowanie...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Błąd importu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translatorcomment>--google--
Nie można otworzyć pliku &apos;%1&apos;
Nie można otworzyć pliku %1! Zostaje on opuszczony.
Nie można otworzyć pliku %1! Zostaje on opuszczony</translatorcomment>
        <translation type="unfinished">Nie można otworzyć pliku</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nie nadaje Importer znaleziono. Proszę sprawdzić format pliku i rozszerzenie.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Proszę sprawdzić prawa dostępu, format pliku i rozszerzenie pliku.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Untitled</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
%1 - [tylko do odczytu]
Otwórz tylko do odczytu...
Tylko do odczytu</translatorcomment>
        <translation type="unfinished">Tylko do odczytu</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Czy chcesz zapisać zmiany wprowadzone w &lt;br&gt; dokument?&apos;&amp;#39;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Twoje zmiany zostaną utracone, jeśli nie je zapisać.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Nowy
Nowy &amp;formularz</translatorcomment>
        <translation type="unfinished">&amp;Nowy</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pl.ts--</translatorcomment>
        <translation type="unfinished">Zamykanie rysunku...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translatorcomment>--exact match--
--file: qt_help_pl.ts--
Nienazwany
(Nienazwany)</translatorcomment>
        <translation type="unfinished">Nienazwany</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Ładowanie...</translatorcomment>
        <translation type="obsolete">Ładowanie...</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Błąd importu</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translatorcomment>--google--
Nie można otworzyć pliku &apos;%1&apos;
Nie można otworzyć pliku %1! Zostaje on opuszczony.
Nie można otworzyć pliku %1! Zostaje on opuszczony</translatorcomment>
        <translation type="unfinished">Nie można otworzyć pliku</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nie nadaje Importer znaleziono. Proszę sprawdzić format pliku i rozszerzenie.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Proszę sprawdzić prawa dostępu, format pliku i rozszerzenie pliku.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Untitled</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
%1 - [tylko do odczytu]
Otwórz tylko do odczytu...
Tylko do odczytu</translatorcomment>
        <translation type="unfinished">Tylko do odczytu</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Czy chcesz zapisać zmiany wprowadzone w &lt;br&gt; dokument?&apos;&amp;#39;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Twoje zmiany zostaną utracone, jeśli nie je zapisać.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Nowy
Nowy &amp;formularz</translatorcomment>
        <translation type="unfinished">&amp;Nowy</translation>
    </message>
</context>
</TS>
